# Changelog

## v1.0.0
Initial Release

## v1.0.1
Bug Fixes

- change ssize_t to long int
- update readme

## v1.0.2
Update manifest

- Change wheel build method

## v1.1.0
Multithreading

- Add support for mutlithreading the `Model` class
- Fix __len__ property 
